//  -*- c++ -*-

#ifndef XPATH_VALUE_H
#define XPATH_VALUE_H

namespace XPath {

class NodeSet;
class Boolean;
class Number;
class String;

/**
 * An XPath value.
 * See REC-xpath-19991116 1.0 Section 1.
 *
 * @version $Id: xmldemo.h,v 1.3 2002/02/18 00:45:47 rich Exp $
 * @author Richard Moore, rich@kde.org 
 */
class Value
{
public:
    enum ValueType {
	ValueNull, ValueNodeSet, ValueBoolean, ValueNumber, ValueString
    };

    Value() : tp(ValueNull) {}
    Value( const Value &res );
    virtual ~Value() {}

    ValueType type() const { return tp; }

    NodeSet toNodeSet();
    Boolean toBoolean();
    Number toNumber();
    String toString();

protected:
    Value( ValueType t ) : tp(t) {}

private:
    ValueType tp;
};


/**
 * An XPath String value.
 * See REC-xpath-19991116 1.0 Section 1.
 */
class String : public Value
{
public:
    String() : Value(ValueString) {}
    String( const String &s ) : Value(ValueString), val(s.val) {}
    String( const QString &s ) : Value(ValueString), val(s) {}
    String( const char *s ) : Value(ValueString), val(s) {}
    virtual ~String() {}

private:
};

/**
 * An XPath node-set value.
 * See REC-xpath-19991116 1.0 Section 1.
 */
class NodeSet : public Value
{
public:
    NodeSet();
    NodeSet( const NodeSet &ns );
    virtual ~NodeSet();

private:
    DOM::NodeList val;
};

/**
 * An XPath Boolean value.
 * See REC-xpath-19991116 1.0 Section 1.
 */
class Boolean : public Value
{
public:
    Boolean();
    Boolean( const Boolean &b );
    virtual ~Boolean();

private:
    bool val;
};

/**
 * An XPath Number value.
 * See REC-xpath-19991116 1.0 Section 1.
 */
class Number : public Value
{
public:
    Number() : Value(ValueNumber) {}
    Number( const Number &n ) : Value(ValueNumber) { this->val = n.val; }

private:
    double val;
};

}; // namespace XPath

#endif // XPATH_VALUE_H

// Local Variables:
// c-basic-offset: 4
// End:
