#include <kdebug.h>

#include "xpath_node.h"

namespace XPath {

//
// XPathNode
//

XPathNode::XPathNode()
{
    type = NullNode;
}

XPathNode::XPathNode( const XPathNode &n )
{
    type = n.type;
}

XPathNode::XPathNode( XPathNode::NodeType nt )
{
    type = nt;
}

XPathNode::~XPathNode()
{

}

DOM::String XPathNode::string() const
{
    if ( type == NullNode )
	return DOM::String("XPathNode::Null");

    return DOM::String();
}

//
// AxisNode
//

Axis::Axis()
    : XPathNode( AxisNode ),
      atype( NullAxis )
{
}

Axis::Axis( const Axis &node )
    : XPathNode( AxisNode ),
      atype( node.atype )
{
}

Axis::Axis( AxisType at )
    : XPathNode( AxisNode ),
      atype( at )
{
}

Axis::~Axis()
{
}

DOM::String Axis::name() const
{
    const char *names[] = {
	"null_axis",
	"child", "descendent", "parent", "ancestor",
	"following-sibling", "preceding-sibling",
	"following", "preceding",
	"attribute", "namespace",
	"self", "descendent-or-self", "ancestor-or-self",
	0
    };

    return DOM::String( names[atype] );
}

DOM::String Axis::string() const
{
    return name();
}

//
// BinaryOpNode
//

BinaryOp::BinaryOp()
    : XPathNode( BinaryOpNode ),
      botype( NullBinaryOp )
{
}

BinaryOp::BinaryOp( const BinaryOp &node )
    : XPathNode( BinaryOpNode ),
      botype( node.botype )
{
}

BinaryOp::BinaryOp( BinaryOpType bot )
    : XPathNode( BinaryOpNode ),
      botype( bot )
{
}

BinaryOp::~BinaryOp()
{
}

DOM::String BinaryOp::name() const
{
    const char *names[] = {
	"null-operator",
	"or", "and", "=",
	"<", ">", "<=", ">=",
	"+", "-", "*", "div", "mod",
	0
    };

    return DOM::String( names[botype] );
}

DOM::String BinaryOp::string() const
{
    return name();
}

//
// FunctionCallNode
//

FunctionCall::FunctionCall()
    : XPathNode( FunctionCallNode ),
      ftype( NullFunction )
{
}

FunctionCall::FunctionCall( const FunctionCall &node )
    : XPathNode( FunctionCallNode ),
      ftype( node.ftype )
{
}

FunctionCall::FunctionCall( FunctionType ft )
    : XPathNode( FunctionCallNode ),
      ftype( ft )
{
}

FunctionCall::~FunctionCall()
{
}

DOM::String FunctionCall::name() const
{
    const char *names[] = {
	"null_function",
	"last", "position", "count",
	"id", "local-name", "namespace-uri", "name",
	"string", "concat", "startswith", "contains",
	"substring-before", "substring-after", "substring",
	"string-length", "normalize-space", "translate",
	"boolean", "not", "true", "false", "lang",
	"number", "sum", "floor", "ceiling", "round", 
	0
    };

    return DOM::String( names[ftype] );
}

DOM::String FunctionCall::qstring() const
{
    return name();
}

}; // namespace XPath


// Local Variables:
// c-basic-offset: 4
// End:
