/*
 *  This file is part of the KDE libraries
 *  Copyright (C) 2004 Richard Moore, rich@kde.org
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "xpath_operator.h"

namespace XPath {

Operator::Operator( OperatorId oid )
    : id(oid)
{
}

Operator::~Operator()
{
}

Value Operator::evaluate()
{
    switch(id) {
	case OperatorOr:
	{
	    bool left = argBoolean(0).value();
	    bool right = argBoolean(1).value();
	    return Boolean( left || right );
	}
	break;
	case OperatorAnd:
	{
	    bool left = argBoolean(0).value();
	    bool right = argBoolean(1).value();
	    return Boolean( left && right );
	}
	break;
	case OperatorEqual:
	{
	}
	break;
	case OperatorNotEqual:
	{
	}
	break;
	case OperatorLessThan:
	{
	    int left = argNumber(0).value();
	    int right = argNumber(1).value();
	    return Number( left < right );
	}
	break;
	case OperatorGreaterThan:
	{
	    int left = argNumber(0).value();
	    int right = argNumber(1).value();
	    return Number( left > right );
	}
	break;
	case OperatorLessThanEquals:
	{
	    int left = argNumber(0).value();
	    int right = argNumber(1).value();
	    return Number( left <= right );
	}
	break;
	case OperatorGreaterThanEquals:
	{
	    int left = argNumber(0).value();
	    int right = argNumber(1).value();
	    return Number( left >= right );
	}
	break;
	case OperatorMinus:
	{
	    int left = argNumber(0).value();
	    return Number( -left );
	}
	break;
    }
}

} // namespace XPath

