// -*- c++ -*-

/*
 *  This file is part of the KDE libraries
 *  Copyright (C) 2004 Richard Moore, rich@kde.org
 *  Copyright (C) 2004 Zack Rusin, zack@kde.org
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef XPATH_SESSION_H
#define XPATH_SESSION_H

#include "dom/dom_string.h"

namespace DOM {
    class DocumentImpl;
    class Document;
}

namespace XPath {

class Value;

/**
 * The central class through which this XPath implementation is used.
 *
 * @author Richard Moore, rich@kde.org
 */
class Session
{
public:
    /**
     * Creates a session in which XPath queries can be executed for the
     * specified document.
     */
    Session( const DOM::Document &document );
    Session( const Session &other );
public:
    Session& operator=( const Session &other );
    Session& operator=( const DOM::Document &other );
    ~Session();

    /**
     * Executes an XPath query against the current document and returns
     * the results.
     *
     * @param query The XPath expression to be executed.
     *
     * @return The value resulting from the execution of the specified
     * XPath query.
     *
     * @exception XPathException
     * This exception is thrown if the evaluation of the query fails.
     */
    Value select( const DOM::DOMString &query );

private:
    DOM::DocumentImpl *doc;
};

} // namespace XPath

#endif // XPATH_SESSION_H

// Local Variables:
// c-basic-offset: 4
// End:
